@@ -8,7 +8,7 @@
 
 "MCMCpoisson" <-
   function(formula, data = parent.frame(), burnin = 1000, mcmc = 10000,
-           thin=1, tune=1.1, verbose = FALSE, seed = NA, beta.start = NA,
+           thin=1, tune=1.1, verbose = 0, seed = NA, beta.start = NA,
            b0 = 0, B0 = 0, ...) {
     
     ## checks
